# Global functions
::: platypus.V
    :docstring:

::: platypus.E
    :docstring:

## Graph generators

::: platypus.P
    :docstring:

::: platypus.C
    :docstring:

::: platypus.K
    :docstring:

::: platypus.S
    :docstring:    
